//#define XERR
//#include "survival.ih"
//
//void Survival::vsdRow() const
//{
////xerr(d_vsdRow << ' ' << d_vsdMatrix[d_vsdRow].size() << ' ' <<\x
////d_vsdMatrix[d_vsdRow][0].value() << ' ' <<\x
////d_vsdMatrix[d_vsdRow][1].value() << ' ' <<\x
////d_vsdMatrix[d_vsdRow][2].value() << ' ' <<\x
////d_vsdMatrix[d_vsdRow][3].value() << ' ' <<\x
////d_vsdMatrix[d_vsdRow][4].value() );
//
//}
//
