// //#define XERR
// #include "random.ih"
//
// double Random::exponential(double mean)
// {
//     d_exponential.param(ExponentialParams{ 1 / mean });
//     return d_exponential(d_engine);
// }
//
//
