//#define XERR
#include "parser.ih"

Parser::Parser()
{
    initLineInfoVects(s_map);               // define d_lines[0]
                                            // at s_map's deepest
                                            // nesting levels
}
