#define XERR
#include "mammo.ih"

void Mammo::setBeta()
{
    base().back() = "beta:";

//    if (Parser::hasSection(base()))
        d_beta = Parser::VSDparameters(VARY_MEAN, base(), 4);
//    else
//        d_beta = Parser::VSDparameters(VARY_MEAN, { "beta:" }, 4);

}
