#title, #author, #date, #affiliation
{
    text-align: center;
}

.lcell  { text-align: left; }
.rcell  { text-align: right; }
.vcell  { vertical-align: top; }
.vlcell { vertical-align: top; text-align: left; }
.vrcell { vertical-align: top; text-align: right; }

body
{
    max-width: 800px;
    padding: 0 1em;
    margin: 0 auto;
/*
    line-height: 1.5;
    font-size: 120%;
*/
}

pre
{
    background-color: #f3f3f3;
    padding: 1em 1ex;
    overflow-x: auto;
}

code
{
    white-space: nowrap;
}
