// //#define XERR
// #include "loop.ih"
// 
// // Woman dies because of natural cause before screening and
// // does not have tumor or dies before self-detecting the tumor
// 
// void Loop::preTumorDeath()
// {
//     setStatus(NATURAL_PRE, d_naturalDeathAge);
//                                                 // would have developed a
//     if (d_tumor.selfDetectable())               // tumor. Compute the tumor's
//         d_tumor.characteristicsAt(d_deathAge);  // characteristics
// }
// 
