////#define XERR
//#include "incidence.ih"
//
//// static
//bool Incidence::stdDev(StringVect &base, double &sd)
//{
//    base.back() =  "stdDev:";
//
//    return Parser::nonNegative(base, sd);
//}
//
