// //#define XERR
// #include "loop.ih"
// 
// void Loop::preSelfDetected()
// {
//     d_roundDetected = 0;                // pre-screen tumor detected
//     characteristics(NATURAL_PRE, SELF_PRE);
// }
// 
// 
