////#define XERR
//#include "incidence.ih"
//
//void Incidence::riskTable()
//{
//    for (auto const &str: base)
//        cerr << str << ' ';
//
//    Parser::Lines lines = Parser::any(base);
//    size_t age;
//    double value;
//    cerr << "got " << lines.size() << " lines\n";
//
//    LineInfo const *ptr;
//    while ((ptr = lines.get()))
//    {
//        istringstream tail{ ptr->tail };
//        while (tail >> age >> value)
//          cerr << "age: " << age << ", value: " << value << '\n';
//    }
//}
//
