//#define XERR
#include "random.ih"

// static
Random &Random::initialize()
{
//    if (s_random)
//        throw Exception{} << "Random::initiaize already called";
    s_random.reset(new Random);
    return *s_random;
}
