////#define XERR
//#include "incidence.ih"
//
//// static 
//bool Incidence::onlyRiskTable(StringVect &base)
//{
//    for (string const &type: 
//                        StringVect{ "lifetimeRisk:", "meanAge:", "stdDev:" })
//    {
//        base.back() = type;
//        if (Parser::hasSection(base))   // incompatible with riskTable:
//        {
//            Err::msg(Err::TABLEPARAMS) << 
//                        " cannot be specified together with 'riskTable:'\n";
//            return false;
//        }
//    }
//
//    base.back() = "riskTable:";
//
//    return true;
//}
//
