//#define XERR
//#include "incidence.ih"
//
////static
//bool Incidence::lifetimeRisk(StringVect &base, VSD &vsd)
//{
//    base.back() =  "lifetimeRisk:";
//    return Parser::one(base, vsd );
//}
//
